==> xlniuxdata-vipgame-1.0.33-20151111.083157-27-sources.jar: com/xunlei/niux/data/vipgame/dao/tasks/TaskGameConfigDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.tasks;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.dto.tasks.TaskGameConfigDTO;
import com.xunlei.niux.data.vipgame.dto.tasks.TaskGameConfigWithUrlDTO;
import com.xunlei.niux.data.vipgame.vo.tasks.TaskDutyConfig;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by jamesjxin on 14-6-12.
 */
public class TaskGameConfigDaoImpl extends BaseDaoImpl implements TaskGameConfigDao {

    @Override
    public List<TaskGameConfigDTO> getAllTaskGameConfigDTOList() {
        return null;
    }

    @Override
    public List<TaskGameConfigWithUrlDTO> getAllTaskGameConfigWithUrlDTO(String channelId){
        final List<TaskGameConfigWithUrlDTO> taskGameConfigWithUrlDTOList = new ArrayList<TaskGameConfigWithUrlDTO>();

        String sql = "select * from taskgameconfig tgc left join\n" +
                "(select gameId, gca.muliPhotoUrl from mobileGameApk ga left join mobileGameChannelApk gca \n" +
                "on gca.apkId = ga.apkId\n" +
                "where gca.channleApkStatus = 3 and gca.channelId=?) as a\n" +
                "on tgc.gameId = a.gameId\n" +
                "order by showOrder desc;";

        Object[] param = new Object[]{channelId};

        getJdbcTemplate().query(sql,param, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException{
                TaskGameConfigWithUrlDTO taskGameConfigWithUrlDTO = new TaskGameConfigWithUrlDTO();
                String muliPhotoUrl = resultSet.getString("muliPhotoUrl");

                taskGameConfigWithUrlDTO.setMuliPhotoUrl(StringUtils.isEmpty(muliPhotoUrl) ? "" : muliPhotoUrl);
                taskGameConfigWithUrlDTO.setEditBy(resultSet.getString("editBy"));
                taskGameConfigWithUrlDTO.setEditTime(resultSet.getString("editTime"));
                taskGameConfigWithUrlDTO.setGameId(resultSet.getString("gameId"));
                taskGameConfigWithUrlDTO.setInputBy(resultSet.getString("inputBy"));
                taskGameConfigWithUrlDTO.setInputTime(resultSet.getString("inputTime"));
                taskGameConfigWithUrlDTO.setIsRecommend(resultSet.getBoolean("isRecommend"));
                taskGameConfigWithUrlDTO.setPicUrl(resultSet.getString("picUrl"));
                taskGameConfigWithUrlDTO.setSeqId(resultSet.getLong("seqId"));
                taskGameConfigWithUrlDTO.setShowOrder(resultSet.getInt("showOrder"));
                taskGameConfigWithUrlDTO.setTask1ref(resultSet.getInt("task1ref"));
                taskGameConfigWithUrlDTO.setTask2ref(resultSet.getInt("task2ref"));
                taskGameConfigWithUrlDTO.setTask3ref(resultSet.getInt("task3ref"));
                taskGameConfigWithUrlDTO.setTask4ref(resultSet.getInt("task4ref"));


                taskGameConfigWithUrlDTOList.add(taskGameConfigWithUrlDTO);
            }
        });

        return taskGameConfigWithUrlDTOList;
    }
}

==> xlniuxdata-vipgame-1.0.54-sources.jar: com/xunlei/niux/data/vipgame/dao/tasks/TaskGameConfigDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.tasks;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.dto.tasks.TaskGameConfigDTO;
import com.xunlei.niux.data.vipgame.dto.tasks.TaskGameConfigWithUrlDTO;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by jamesjxin on 14-6-12.
 */
public class TaskGameConfigDaoImpl extends BaseDaoImpl implements TaskGameConfigDao {

    @Override
    public List<TaskGameConfigDTO> getAllTaskGameConfigDTOList() {
        return null;
    }

    @Override
    public List<TaskGameConfigWithUrlDTO> getAllTaskGameConfigWithUrlDTO(String channelId){
        final List<TaskGameConfigWithUrlDTO> taskGameConfigWithUrlDTOList = new ArrayList<TaskGameConfigWithUrlDTO>();

//        String sql = "select * from taskgameconfig tgc left join\n" +
//                "(select gameId, gca.muliPhotoUrl from mobileGameApk ga left join mobileGameChannelApk gca \n" +
//                "on gca.apkId = ga.apkId\n" +
//                "where gca.channleApkStatus = 3 and gca.channelId=?) as a\n" +
//                "on tgc.gameId = a.gameId\n" +
//                "order by showOrder desc;";

        String sql = "select editBy, editTime, tgc.gameId, inputBy, inputTime, isRecommend, picUrl, tgc.seqId, showOrder, task1ref, task2ref, task3ref, task4ref, muliPhotoUrl from taskgameconfig tgc left join (\n" +
                "select * from commonspreadinfo where advNo=? and isValid=1\n" +
                ") as a\n" +
                "on tgc.gameId = a.gameId\n" +
                "order by showOrder desc;";

        Object[] param = new Object[]{channelId};

        getJdbcTemplate().query(sql,param, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException{
                TaskGameConfigWithUrlDTO taskGameConfigWithUrlDTO = new TaskGameConfigWithUrlDTO();
                String muliPhotoUrl = resultSet.getString("muliPhotoUrl");

                taskGameConfigWithUrlDTO.setMuliPhotoUrl(StringUtils.isEmpty(muliPhotoUrl) ? "" : muliPhotoUrl);
                taskGameConfigWithUrlDTO.setEditBy(resultSet.getString("editBy"));
                taskGameConfigWithUrlDTO.setEditTime(resultSet.getString("editTime"));
                taskGameConfigWithUrlDTO.setGameId(resultSet.getString("gameId"));
                taskGameConfigWithUrlDTO.setInputBy(resultSet.getString("inputBy"));
                taskGameConfigWithUrlDTO.setInputTime(resultSet.getString("inputTime"));
                taskGameConfigWithUrlDTO.setIsRecommend(resultSet.getBoolean("isRecommend"));
                taskGameConfigWithUrlDTO.setPicUrl(resultSet.getString("picUrl"));
                taskGameConfigWithUrlDTO.setSeqId(resultSet.getLong("seqId"));
                taskGameConfigWithUrlDTO.setShowOrder(resultSet.getInt("showOrder"));
                taskGameConfigWithUrlDTO.setTask1ref(resultSet.getInt("task1ref"));
                taskGameConfigWithUrlDTO.setTask2ref(resultSet.getInt("task2ref"));
                taskGameConfigWithUrlDTO.setTask3ref(resultSet.getInt("task3ref"));
                taskGameConfigWithUrlDTO.setTask4ref(resultSet.getInt("task4ref"));


                taskGameConfigWithUrlDTOList.add(taskGameConfigWithUrlDTO);
            }
        });

        return taskGameConfigWithUrlDTOList;
    }
}
